from distutils.core import setup

setup(

	name	= 'gDownloader',
	version	= '1.9',
	description = 'GM Playlist Downloader',
	long_description = open( 'README.txt' , 'rt' ).read(),
	author = 'ceberous',
	author_email = 'cerbus.collin@gmail.com',
	url = 'https://github.com/ceberous/GPMDownloader.git',
	py_modules=['gDownloader']
)